/*
Copyright 2021 The Hybridnet Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"context"
	"time"

	v1 "github.com/alibaba/hybridnet/pkg/apis/networking/v1"
	scheme "github.com/alibaba/hybridnet/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// RemoteVtepsGetter has a method to return a RemoteVtepInterface.
// A group's client should implement this interface.
type RemoteVtepsGetter interface {
	RemoteVteps() RemoteVtepInterface
}

// RemoteVtepInterface has methods to work with RemoteVtep resources.
type RemoteVtepInterface interface {
	Create(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.CreateOptions) (*v1.RemoteVtep, error)
	Update(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.UpdateOptions) (*v1.RemoteVtep, error)
	UpdateStatus(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.UpdateOptions) (*v1.RemoteVtep, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.RemoteVtep, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.RemoteVtepList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.RemoteVtep, err error)
	RemoteVtepExpansion
}

// remoteVteps implements RemoteVtepInterface
type remoteVteps struct {
	client rest.Interface
}

// newRemoteVteps returns a RemoteVteps
func newRemoteVteps(c *NetworkingV1Client) *remoteVteps {
	return &remoteVteps{
		client: c.RESTClient(),
	}
}

// Get takes name of the remoteVtep, and returns the corresponding remoteVtep object, and an error if there is any.
func (c *remoteVteps) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.RemoteVtep, err error) {
	result = &v1.RemoteVtep{}
	err = c.client.Get().
		Resource("remotevteps").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of RemoteVteps that match those selectors.
func (c *remoteVteps) List(ctx context.Context, opts metav1.ListOptions) (result *v1.RemoteVtepList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.RemoteVtepList{}
	err = c.client.Get().
		Resource("remotevteps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested remoteVteps.
func (c *remoteVteps) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("remotevteps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a remoteVtep and creates it.  Returns the server's representation of the remoteVtep, and an error, if there is any.
func (c *remoteVteps) Create(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.CreateOptions) (result *v1.RemoteVtep, err error) {
	result = &v1.RemoteVtep{}
	err = c.client.Post().
		Resource("remotevteps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(remoteVtep).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a remoteVtep and updates it. Returns the server's representation of the remoteVtep, and an error, if there is any.
func (c *remoteVteps) Update(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.UpdateOptions) (result *v1.RemoteVtep, err error) {
	result = &v1.RemoteVtep{}
	err = c.client.Put().
		Resource("remotevteps").
		Name(remoteVtep.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(remoteVtep).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *remoteVteps) UpdateStatus(ctx context.Context, remoteVtep *v1.RemoteVtep, opts metav1.UpdateOptions) (result *v1.RemoteVtep, err error) {
	result = &v1.RemoteVtep{}
	err = c.client.Put().
		Resource("remotevteps").
		Name(remoteVtep.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(remoteVtep).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the remoteVtep and deletes it. Returns an error if one occurs.
func (c *remoteVteps) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	return c.client.Delete().
		Resource("remotevteps").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *remoteVteps) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("remotevteps").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched remoteVtep.
func (c *remoteVteps) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.RemoteVtep, err error) {
	result = &v1.RemoteVtep{}
	err = c.client.Patch(pt).
		Resource("remotevteps").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
